[CalendarServer-changes] [14719] CalendarServer/trunk/calendarserver/tap/test/test_caldav.py

source_changes at macosforge.org source_changes at macosforge.org
Wed Apr 29 06:23:53 PDT 2015


Revision: 14719
          http://trac.calendarserver.org//changeset/14719
Author:   cdaboo at apple.com
Date:     2015-04-29 06:23:53 -0700 (Wed, 29 Apr 2015)
Log Message:
-----------
Make test work in non-IPv6 environment.

Modified Paths:
--------------
    CalendarServer/trunk/calendarserver/tap/test/test_caldav.py

Modified: CalendarServer/trunk/calendarserver/tap/test/test_caldav.py
===================================================================
--- CalendarServer/trunk/calendarserver/tap/test/test_caldav.py	2015-04-28 14:09:08 UTC (rev 14718)
+++ CalendarServer/trunk/calendarserver/tap/test/test_caldav.py	2015-04-29 13:23:53 UTC (rev 14719)
@@ -444,6 +444,7 @@
             self.assertEquals(socketService.gid, self.alternateGroup)
 
 
+
 class TestLoggingProtocol(LoggingProtocol):
 
     def processEnded(self, reason):
@@ -451,6 +452,7 @@
         self.service.processEnded(self.name)
 
 
+
 class TestProcessMonitor(ProcessMonitor):
 
     def startProcess(self, name):
@@ -473,6 +475,7 @@
             proto, args[0], args, uid=uid, gid=gid, env=env
         )
 
+
     def stopService(self):
         """
         Return a deferred that fires when all child processes have ended.
@@ -501,6 +504,8 @@
             if deferred is not None:
                 deferred.callback(None)
 
+
+
 class MemcacheSpawner(TestCase):
 
     def setUp(self):
@@ -640,8 +645,8 @@
                     serviceArgs[0],
                     dict(expectedSubServices)[serviceClass]
                 )
-        # TCP+SSL services for IPv4, TCP+SSL services for IPv6.
-        self.assertEquals(checked, 4)
+        # TCP+SSL services for each bind address
+        self.assertEquals(checked, 2 * len(config.BindAddresses))
 
 
     def test_SSLKeyConfiguration(self):
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <https://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20150429/94653d96/attachment.html>


More information about the calendarserver-changes mailing list